Tutorials — ASE documentation

### Navigation

- index
- modules |

# Tutorials

## Python

If you are not familiar with Python please read What is Python?.

- What is Python?
  - Executing Python code
  - Types
  - Loops
  - Functions and classes
  - Importing modules

## ASE

Most of the tutorials will use the `EMT` potential, but any other `Calculator` could be plugged in instead.

- Introduction: Nitrogen on copper
- Manipulating atoms
- Atomization energy
- Finding lattice constants
- Equation of state
- Diffusion of gold atom on Al(100) surface (constraint)
- Self-diffusion on the Al(110) surface (NEB + Dimer method exercise)
- Diffusion of gold atom on Al(100) surface (NEB)
- Image Dependent Pair Potential for improved interpolation of NEB initial guess
- Dissociation tutorial
- Using the spacegroup subpackage
- Molecular dynamics
- Partly occupied Wannier Functions
- Constrained minima hopping (global optimization)
- Optimization with a Genetic Algorithm
- GA Search for stable FCC alloys

## NumPy

If your ASE scripts make extensive use of matrices you may want to familiarize yourself with Numeric arrays in Python.

- Numeric arrays in Python

## Further reading

For more details:

- Look at the documentation for the individual `modules`.
- See the automatically generated documentation `Epydoc`: ase.
- Browse the source code online.
- Have a look at `siesta` exercises:

- Exercises
  - Siesta 1: Basis Sets
    - Part 1: Standard basis sets
    - Part 2: Optimized basis sets
    - Tips
  - Siesta 2: Molecular Dynamics

## Videos

The following video tutorials are available:

> - Overview and installation of ASE, by Anthony Goodrow (duration: ~5min 30sec; size: 26 MB) - en:

### Navigation

- index
- modules |